
# Type: gene to expression site association_quantifier qualifier




URI: [biolink:gene_to_expression_site_association_quantifier_qualifier](https://w3id.org/biolink/vocab/gene_to_expression_site_association_quantifier_qualifier)


## Domain and Range

[GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md) ->  <sub>OPT</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [quantifier qualifier](quantifier_qualifier.md)

## Children


## Used by

 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)
